#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod
version:              1.6.2.1
visibility:           public
id:                   yesod-1.6.2.1-4KjmlImCWpVBo2iFJDZtJD
key:                  yesod-1.6.2.1-4KjmlImCWpVBo2iFJDZtJD
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>

category:             Web, Yesod
abi:                  63a5e0ea1ee796e8678bd5ca6770fdc4
exposed:              True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-1.6.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-1.6.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-1.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod
hs-libraries:         HSyesod-1.6.2.1-4KjmlImCWpVBo2iFJDZtJD
depends:
    aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-8P16HBmakUKG1It6ArZYEY
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc directory-1.3.8.5
    fast-logger-3.2.4-BcBZzOAKBToBJfOfnajTCu
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    monad-logger-0.3.42-B6FuRrtxJsW9ScQYwgkZAV
    shakespeare-2.1.7.1-1COXynUMrU9JuSWUq55esW
    streaming-commons-0.2.3.1-CD29ujDIwjv88YwbpR0Txf
    template-haskell-2.20.0.0 text-2.0.2 unix-2.8.4.0
    unordered-containers-0.2.20.1-HfKtyefgs0b2egKrxLGXU0
    wai-3.2.4-3XyCh5m71lWJYF48VLLZUp
    wai-extra-3.1.18-LZb0ZvCfLGtGdgg4u5HHu3
    wai-logger-2.5.0-DXGT5hmM8jS3TVtROXC2tb
    warp-3.4.0-9HslBeBY1wf9o4ROK9xeo9
    yaml-0.11.11.2-3BCv4CO4LZa5ROi1TocCLv
    yesod-core-1.6.27.1-5nww1PtNlse5fK9VkYdWN4
    yesod-form-1.7.9.2-9vOWCdvhIzxHuOiHsqsh6D
    yesod-persistent-1.6.0.8-AwjY9pP7CjiI11gglD6X9I

haddock-interfaces:   /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html:         /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

